@@ -17,7 +17,7 @@ test_that("PipeOp - General functions", {
   expect_output(expect_equal(po_1$train(list(1)), list(output = 1)), "Training debug.basic")
   expect_equal(po_1$state, list(input = 1))
   expect_true(po_1$is_trained)
-  expect_error(po_1$train(tsk("iris")), regexp = "Must be of type 'list'")
+  expect_error(po_1$train(tsk("iris")), regexp = "type 'list'")
 })
 
 
